##  1. Modeling middleware as an Application:
Pros:
  * Provides visibility on most LeanIX reports, as they are application-centric.
  * Enables application rationalization modeling through Interfaces.
  * Enables data flow diagrams within LeanIX.
  * Enables the Business Capabilities and User Group relations view in reporting.


Cons:
  * Does not allow for a clear view on IT landscape reports, unless double-modeled (see below).
  * Visualizing data flow between 2 applications becomes challenging.
  * Needs to be double-modeled as an IT component as well in order to enable Technology Matrix and
Landscape reporting within LeanIX.
  * Not efficient when using Fact Sheet count.

![2018](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748a8e97a441014a1e5c9e1a81ea249_LowRes.png)
